(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4417,        135]*)
(*NotebookOutlinePosition[      5060,        157]*)
(*  CellTagsIndexPosition[      5016,        153]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(<< Graphics`Fractals`\)], "Input"],

Cell["\<\
The following are examples of density plots for different fractals with \
different parameters, later are examples of contour plots of the fractals.\
\>", "Text"],

Cell[BoxData[
    \(JuliaPlot[{x, \(-1.5\), 1.5}, {y, \(-1.5\), 1.5}]\)], "Input"],

Cell[BoxData[
    \(MandelbrotPlot[{x, \(-2\), 0.75}, {y, \(-1.25\), 1.25}, 
      ColorFunction \[Rule] Hue]\)], "Input"],

Cell[BoxData[
    \(MandelbrotPlot[{x, \(-0.5\), 0.75}, {y, \(-1.25\), 0}]\)], "Input"],

Cell["\<\
If you need more resolusion modify PlotPoints, for a 400x400 pixels image use \
PlotPoints\[Rule]400:\
\>", "Text"],

Cell[BoxData[
    \(MandelbrotPlot[{x, \(-0.5\), 0.75}, {y, \(-1.25\), 0}, 
      PlotPoints \[Rule] 400]\)], "Input"],

Cell[BoxData[
    \(NewtonRootsPlot[{x, \(-2\), 2}, {y, \(-2\), 2}, 
      ColorFunction -> Hue]\)], "Input"],

Cell[BoxData[
    \(NewtonRootsPlot[{x, \(-2\), 2}, {y, \(-2\), 2}, Order \[Rule] 7, 
      ColorFunction -> Hue]\)], "Input"],

Cell["\<\
The julia set with const\[Rule]-0.74543+0.11301*I apears in an article of \
\"Investigaci\[OAcute]n y Ciencia\" (Spanish version of \"Sientific \
America\"):\
\>", "Text"],

Cell[BoxData[
    \(JuliaPlot[{x, \(-1.5\), 1.5}, {y, \(-0.9\), 0.9}, 
      Const \[Rule] \(-0.74543\) + 0.11301  I, 
      ColorFunction -> \((RGBColor[#, 0, 0] &)\), Maxiter -> 512]\)], "Input"],

Cell["\<\
You can make copntour plots of the fractals, for example, the contour plot of \
the Julia set is:\
\>", "Text"],

Cell[BoxData[
    \(JuliaContourPlot[{x, \(-1.5\), 1.5}, {y, \(-1.5\), 1.5}, 
      PlotPoints \[Rule] 200]\)], "Input"],

Cell["\<\
The next, plot the contour whit value 70 of one of the above examples:\
\>", "Text"],

Cell[BoxData[
    \(JuliaContourPlot[{x, \(-1.5\), 1.5}, {y, \(-0.9\), 0.9}, 
      Const -> \(-0.74543\) + 0.11301*I, 
      ColorFunction -> \((RGBColor[#, 0, 0] &)\), PlotPoints \[Rule] 256, 
      Contours \[Rule] {60}]\)], "Input"],

Cell["This plot five contours of Newton-Raphson fractal:", "Text"],

Cell[BoxData[
    \(NewtonRootsContourPlot[{x, \(-2\), 2}, {y, \(-2\), 2}, 
      PlotPoints \[Rule] 256, Maxiter \[Rule] 256, 
      Contours \[Rule] 5]\)], "Input"],

Cell[TextData[{
  "If you need contour contour shading use ",
  StyleBox["ContourShading", "MR"],
  " ->True option, and if you want a particular form of coloring, use  \
ColorFunction option:"
}], "Text"],

Cell[BoxData[
    \(NewtonRootsContourPlot[{x, \(-2\), 2}, {y, \(-2\), 2}, 
      PlotPoints \[Rule] 256, Maxiter \[Rule] 256, Contours \[Rule] 5, 
      ContourShading \[Rule] True, \ ColorFunction \[Rule] Hue]\)], "Input"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1152}, {0, 781}},
WindowSize->{738, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 54, 1, 30, "Input"],
Cell[1811, 54, 172, 3, 52, "Text"],
Cell[1986, 59, 82, 1, 30, "Input"],
Cell[2071, 62, 122, 2, 30, "Input"],
Cell[2196, 66, 87, 1, 30, "Input"],
Cell[2286, 69, 125, 3, 33, "Text"],
Cell[2414, 74, 118, 2, 30, "Input"],
Cell[2535, 78, 109, 2, 30, "Input"],
Cell[2647, 82, 126, 2, 30, "Input"],
Cell[2776, 86, 181, 4, 52, "Text"],
Cell[2960, 92, 197, 3, 50, "Input"],
Cell[3160, 97, 121, 3, 33, "Text"],
Cell[3284, 102, 120, 2, 30, "Input"],
Cell[3407, 106, 94, 2, 33, "Text"],
Cell[3504, 110, 236, 4, 50, "Input"],
Cell[3743, 116, 66, 0, 33, "Text"],
Cell[3812, 118, 166, 3, 50, "Input"],
Cell[3981, 123, 205, 5, 52, "Text"],
Cell[4189, 130, 224, 3, 50, "Input"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

